@@ -37,6 +37,7 @@
 #include <kmessagebox.h>
 #include <QUuid>
 #include <QMutexLocker>
+#include <QMap>
 
 
 /* Includes for the STL */
@@ -89,7 +90,11 @@ AIPlayer::~AIPlayer()
   */
 void AIPlayer::actionChoice(GameLogic::GameAutomaton::GameState state)
 {
-  kDebug() << name() << ": (state is " << m_game-> stateName() << ", current player is "<<m_game-> currentPlayer()->name()<<")" << endl;
+  if (m_game && m_game->currentPlayer())
+  {
+    kDebug() << name() << ": (state is " << m_game-> stateName() << ", current player is "
+      << m_game-> currentPlayer()->name()<<")" << endl;
+  }
   if (m_game->m_aicannotrunhack)
   {
     kDebug() << "HACK HACK AIPlayer " << name()   
@@ -243,9 +248,9 @@ void AIPlayer::chooseAttackMoveArmiesOrNextPlayer()
   * Returns a pair of countries where the attacker have enough armies to attack
   * and the defender is a ennemy neighbour of the attacker
   */
-std::pair<const Country*, const Country*> AIPlayer::chooseBelligerant()
+QPair<const Country*, const Country*> AIPlayer::chooseBelligerant()
 {
-  std::multimap<const Country*, const Country*> candidates;
+  QMultiMap<const Country*, const Country*> candidates;
 
 //     kDebug() << name() << " : AIPlayer::chooseBelligerant()" << endl;
     // Builds the list of countries of the player that have enough armies and a good neighbour
@@ -275,7 +280,7 @@ std::pair<const Country*, const Country*> AIPlayer::chooseBelligerant()
           {
 //                        kDebug() << name() << "  choosing belligerants, adding target / source : "
 //                                << candidateSource-> name() << " / " << candidateTarget-> name() << endl;
-              candidates.insert(std::make_pair(candidateSource, candidateTarget));
+              candidates.insert(candidateSource, candidateTarget);
           }
         }
       }
@@ -284,23 +289,23 @@ std::pair<const Country*, const Country*> AIPlayer::chooseBelligerant()
     if ( candidates.size() == 0 )
     {
 //            kDebug() << name() << " OUT AIPlayer::chooseBelligerant() ; map size = 0 ; it isn't possible to attack." << endl;
-      return (std::make_pair(static_cast< Country*>(0), static_cast< Country*>(0)));
+      return (qMakePair<const Country*, const Country*>(static_cast< Country*>(0), static_cast< Country*>(0)));
     }
     uint which = Dice::roll(candidates.size()) - 1;
 //        kDebug() << "Which = " << which <<endl;
-    std::multimap<const Country*, const Country*>::const_iterator it;
+    QMultiMap<const Country*, const Country*>::const_iterator it;
     unsigned int i = 0;
-    for ( it = candidates.begin(); it != candidates.end() ; it++, i++ )
+    for ( it = candidates.constBegin(); it != candidates.constEnd() ; it++, i++ )
     {
       if (which == i )
       {
 //                kDebug() << "OUT AIPlayer::chooseBelligerant() : " << endl ;
-        return (*it);
+         return qMakePair<const Country*, const Country*>(it.key(),it.value());
       }
     }
   }
 //    kDebug() << "OUT AIPlayer::chooseBelligerant() : do I own no country ???" << endl;
-  return (std::make_pair(static_cast< Country* >(0), static_cast< Country* >(0)));
+  return (qMakePair<const Country*, const Country*>(static_cast< Country*>(0), static_cast< Country*>(0)));
 }
 
 /**
@@ -368,7 +373,7 @@ void AIPlayer::stop()
 bool AIPlayer::attackAction() 
 {
 //   kDebug() << "AIPlayer::attackAction" << endl;
-  std::pair<const Country* , const Country* > srcDest = chooseBelligerant();
+  QPair<const Country* , const Country* > srcDest = chooseBelligerant();
   if ( (srcDest.first == 0) || (srcDest.second == 0) )
   {
 //     kDebug() << "AIPlayer::attackAction: no attack available" << endl;
@@ -495,7 +500,7 @@ void AIPlayer::placeArmiesAction()
     const Country* receiver = chooseReceivingCountry();
     if (receiver == 0)
     {
-      QString msg = i18n("Error - No receiving country selected while computer player %1 had still %2 armies to place. This is bug probably #2232 at www.gna.org.", Player::name(), getNbAvailArmies());
+      QString msg = i18np("Error - No receiving country selected while computer player %2 had still 1 army to place. This is bug probably #2232 at www.gna.org.", "Error - No receiving country selected while computer player %2 had still %1 armies to place. This is bug probably #2232 at www.gna.org.", getNbAvailArmies(), Player::name());
       kError() << msg;
       KMessageBox::error(0, msg, i18n("Fatal Error"));
       m_thread.exit();
@@ -640,11 +645,11 @@ void AIPlayer::nextPlayerAction()
   stop();
 }
 
-void AIPlayer::saveXml(std::ostream& xmlStream)
+void AIPlayer::saveXml(QTextStream& xmlStream)
 {
   xmlStream << "<player ai=\"true\" ";
   innerSaveXml(xmlStream);
-  xmlStream << " />" << std::endl;
+  xmlStream << " />" << endl;
 }
 
 /** 
