@@ -28,6 +28,7 @@
 #include "GameLogic/gameautomaton.h"
 #include "GameLogic/player.h"
 #include "GameLogic/country.h"
+#include "Dialogs/InvasionSlider.h"
 #include "Sprites/animspriteslist.h"
 #include "Jabber/jabberclient.h"
 
@@ -56,6 +57,7 @@
 
 class KsirkJabberGameWidget;
 class mainMenu;
+class NewGameSetup;
 
 class QAction;
 class KGameChat;
@@ -82,7 +84,10 @@ namespace Ksirk
   class FightArena;
   class AnimSpritesGroup;
   class KRightDialog;
-  class NewGameDialogImpl;
+  class NewGameWidget;
+  class KPlayerSetupWidget;
+  class NewGameSummaryWidget;
+  class TcpConnectWidget;
   
 namespace Sprites
 {
@@ -110,15 +115,17 @@ class KGameWindow: public KXmlGuiWindow
 
 public:
   enum MessageShowingType {OnConfig, ForceShowing};
-  enum InvasionType {Invasion, Moving};
   enum FightType {Attack, Defense};
   enum TabbedWidgetsIndexesType
   {
     MAINMENU_INDEX /*0*/,
     NEWGAME_INDEX /*1*/,
     JABBERGAME_INDEX /*2*/,
-    MAP_INDEX /*3*/,
-    ARENA_INDEX /*4*/
+    NEWPLAYER_INDEX /*3*/,
+    NEWGAMESUMMARY_INDEX /*4*/,
+    TCPCONNECT_INDEX /*5*/,
+    MAP_INDEX /*6*/,
+    ARENA_INDEX /*7*/
   };
   /**
     * Create the window and initializes its members
@@ -140,7 +147,9 @@ public:
 
   /** Returns the menu graphics view */
   mainMenu* mMenu() {return m_mainMenu;}
-    
+
+  NewGameSetup* newGameSetup() {return m_newGameSetup;}
+  
   /**
     * Ask all the sprites to repaint themselves
     */
@@ -228,18 +237,8 @@ public:
     */
   bool haveMovingArmies() const {return !m_animSpritesGroups.empty();}
 
-  void setNbAttack (int nb);
-
-  void setNbDefense (int nb);
-
-
 /************** END OF METHODS DEFINED IN gestionSprites.cpp *****************/
 
-  /**
-    * Prepares the players for the game with human interaction. Return true
-    * if successful or false if failure or cancel
-    */
-  bool setupPlayers(GameLogic::GameAutomaton::NetworkGameType socket);
   bool setupOnePlayer();
   bool setupOneWaitedPlayer();
   bool createWaitedPlayer(quint32 waitedPlayerId);
@@ -278,6 +277,7 @@ public:
   void clearHighlighting();
   void startLocalCurrentAI();
   void displayDefenseWindow();
+  
   //@}
 
   /**
@@ -575,16 +575,16 @@ public:
   void showMainMenu();
 
   /**
-    * The three types of central widget possible. This enum is used for knowing witch
-    * is currently displayed (see m_currentDisplayedWidget var below).
+    * The three types of possible central widget. This enum is used to know which
+    * one is currently displayed (see m_currentDisplayedWidget member below).
     */
-  enum widgetType {mainMenuType, mapType, arenaType};
+  enum WidgetType {MainMenu, Map, Arena};
 
   /**
     * Give type of the central widget currently displayed.
     * @return current widget type
     */
-  widgetType currentWidgetType();
+  WidgetType currentWidgetType();
 
   /**
     * Give the central widget currently displayed.
@@ -608,14 +608,14 @@ public:
     */
   GameLogic::Player* currentPlayer();
 
-  void slideInvade(GameLogic::Country *,GameLogic::Country *, InvasionType invasionType = Invasion);
+  void slideInvade(GameLogic::Country *,GameLogic::Country *, Ksirk::InvasionSlider::InvasionType invasionType = Ksirk::InvasionSlider::Invasion);
 
   void setNextPlayerActionEnabled(bool value);
   void setSaveGameActionEnabled(bool value);
 
   void updateScrollArrows();
 
-  bool newGameDialog(const QString& skin, bool networkGame);
+  bool newGameDialog(const QString& skin, GameLogic::GameAutomaton::NetworkGameType netGameType);
 
   bool finishSetupPlayers();
 
@@ -641,8 +641,13 @@ public:
   const QString& groupchatRoom() const {return m_groupchatRoom;}
   const QString& groupchatNick() const {return m_groupchatNick;}
   const QString& groupchatPassword() const {return m_groupchatPassword;}
+
+  void joinNetworkGame();
+
+  void updateNewGameSummary();
+  void showNewGameSummary();
   
-  protected:
+protected:
 
   /**
     * Connected to the frame timer, it manages the behavior of the game in
@@ -693,26 +698,14 @@ public:
   void reduceChat();
   void unreduceChat();
 
+
 Q_SIGNALS:
-    void newJabberGame(const QString&, int, const QString&);
+  void newJabberGame(const QString&, int, const QString&);
     
 public Q_SLOTS:
 
   virtual void mouseMoveEvent ( QMouseEvent * event );
 
-  void slideMove(int v);
-  void slideReleased();  
-  void slideClose();
-  //@{
-  /**
-   * The slots associated to the keys
-   * Will initiate different actions depending on the game state
-   */
-  void slotKey1();
-  void slotKey2();
-  void slotKey3();
-  //@}
-  
   //@{
   /**
     * The slots associated to the buttons
@@ -793,10 +786,19 @@ public Q_SLOTS:
   void slotZoomIn();
   void slotZoomOut();
 
-  void slotNewGameOK(unsigned int nbPlayers, const QString& skin, unsigned int nbNetworkPlayers, bool useGoals);
+  void slotNewGameNext();
+//   void slotNewGameOK(unsigned int nbPlayers, const QString& skin, unsigned int nbNetworkPlayers, bool useGoals);
   void slotNewGameKO();
 
   void slotJabberGameCanceled(int previousIndex);
+
+  void slotNewPlayerNext();
+  void slotNewPlayerPrevious();
+  void slotNewPlayerCancel();
+  
+  void slotStartNewGame();
+  void slotTcpConnectCancel();
+  void slotTcpConnectPrevious();
   
 private Q_SLOTS:
   void optionsConfigure();
@@ -897,9 +899,20 @@ private Q_SLOTS:
 /* the unregister task finished */
 //   void slotUnregisterFinished();
   void slotExit();
-  
-private:
 
+  void slotConnectToServer();
+  
+private: // Private methods
+  void createDefenseDialog();
+  void moveArmies(GameLogic::Country& src, GameLogic::Country& dest, unsigned int nb);
+  void saveXml(QTextStream& xmlStream);
+  void loadDices();
+  QPixmap buildDice(const QString& id);
+  void setupPopupMessage();
+  QString defenseLabel();
+
+    
+private: // Private members
   QDockWidget * m_rightDock;
 
   KRightDialog * m_rightDialog;
@@ -908,21 +921,12 @@ private:
 
   GameLogic::GameAutomaton* m_automaton;
 
-  KDialog * m_wSlide;
-
-  int m_nbRArmy;
-  int m_nbLArmy;
-  int m_currentSlideValue;
-  int m_previousSlideValue;
-
-  QLabel * m_nbLArmies;
-  QLabel * m_nbRArmies;
-  QSlider * m_invadeSlide;
+  InvasionSlider * m_wSlide;
 
   /**
     * State that say the widget that is currently displayed between the map and the arena.
     */
-  widgetType m_currentDisplayedWidget;
+  WidgetType m_currentDisplayedWidget;
 
   /**
    * The widget initialy docked at bottom where is displayed the events history
@@ -940,7 +944,7 @@ private:
   int NKD, NKA;
   //@}
   
-  bool ARENA;
+  bool m_useArena;
 
   int nbSpriteAttacking;
   int nbSpriteDefending;
@@ -1077,11 +1081,9 @@ private:
 
   GameLogic::Country* m_mouseLocalisation;
 
-  KDialog * dial;
+  KDialog * m_defenseDialog;
 
   // components that will be re-used of the chat
-  QPixmap m_upChatReducePix;
-  QPixmap m_downChatReducePix;
   QPixmap m_upChatFloatPix;
   QPixmap m_downChatFloatPix;
 
@@ -1102,39 +1104,37 @@ private:
   Sprites::ArrowSprite* m_leftarrow;
   Sprites::ArrowSprite* m_rightarrow;
   
-private: // Private methods
-  /*void attack(GameLogic::Country& attacker, GameLogic::Country& defender, unsigned int nb);*/
-  void moveArmies(GameLogic::Country& src, GameLogic::Country& dest, unsigned int nb);
-  void saveXml(std::ostream& xmlStream);
-  void loadDices();
-  QPixmap buildDice(DiceColor color, const QString& id);
-  void setupPopupMessage();
-
-  bool m_networkGame;
   int m_port;
-  uint m_newPlayersNumber;
-
-  NewGameDialogImpl* m_newGameDialog;
-
+  bool m_reinitializingGame;
+  
+  NewGameWidget* m_newGameDialog;
+  KPlayerSetupWidget* m_newPlayerWidget;
+  
   GameLogic::GameAutomaton::GameState m_stateBeforeNewGame;
   int m_stackWidgetBeforeNewGame;
-
+  
   JabberClient* m_jabberClient;
   XMPP::Jid m_serverJid;
   
   /* Initial presence to set after connecting. */
   XMPP::Status m_initialPresence;
-
+  
   QString m_groupchatHost;
   QString m_groupchatRoom;
   QString m_groupchatNick;
   QString m_groupchatPassword;
-
+  
   QString m_advertizedHostName;
-
+  
   KsirkJabberGameWidget* m_jabberGameWidget;
-
+  
   QSet<QString> m_presents;
+
+  NewGameSetup* m_newGameSetup;
+  NewGameSummaryWidget* m_newGameSummaryWidget;
+  TcpConnectWidget* m_tcpConnectWidget;
+
+  QLabel* m_labDef;
 };
 
 } // closing namespace Ksirk
